@@ -32,8 +32,8 @@ JabberConnector::JabberConnector ( QObject *parent )
 
 	mByteStream = new JabberByteStream ( this );
 
-	connect ( mByteStream, SIGNAL (connected()), this, SLOT (slotConnected()) );
-	connect ( mByteStream, SIGNAL (error(int)), this, SLOT (slotError(int)) );
+	connect ( mByteStream, &JabberByteStream::connected, this, &JabberConnector::slotConnected );
+	connect ( mByteStream, &ByteStream::error, this, &JabberConnector::slotError );
 
 }
 
